-----------------------
-- INFORMATION       --
-----------------------
-- Weeds Gun Game v1.2 for Counter-Strike 2D
-- Based on the original CS2D Gun Game script ("GunGame.lua")
--
-- Created by Rich Weeds Nagel (USGN: 110755) - January 5, 2013
-- http://www.unrealsoftware.de/profile.php?userid=110755
-- richnagel@centurylink.net
-- http://www.richnagel.net
--
-- This Lua script adds a "Gun Game" deathmatch gameplay mode to Counter-Strike
-- 2D for a "listen" server (when starting a new game), as well as for a
-- dedicated server.
--
-- Refer to the included "WeedsGunGame.txt" readme file for complete
-- installation and usage instructions.
--
-- Original CS2D Gun Game Script ("GunGame.lua")
-- Created by Unreal Software - March 11, 2009
-- http://www.unrealsoftware.de


-----------------------
-- INITIAL SETUP     --
-----------------------
if sample==nil then sample={} end
sample.gg={}

function initArray(m)
	local array = {}
	for i = 1, m do
		array[i]=0
	end
	return array
end

-- Level Array (for 32 Players)
sample.gg.level=initArray(32)

-- Kill Counter Array (for 32 Players)
sample.gg.kills=initArray(32)

-- Initialize Join Server Handicap Level
total_number_of_players=0
sum_of_total_players_levels=0
join_server_handicap_level=1


-----------------------
-- GUN GAME SETTINGS --
-----------------------
-- Deathmatch Game Mode Enabled
-- "sv_gamemode 0" = Standard Game Mode Enabled
-- "sv_gamemode 1" = Deathmatch Game Mode Enabled (Default)
-- "sv_gamemode 2" = Team Deathmatch Game Mode Enabled
-- "sv_gamemode 3" = Construction Game Mode Enabled
-- "sv_gamemode 4" = Zombies! Game Mode Enabled
-- parse("sv_gamemode 1") -- Original CS2D Gun Game Default
parse("sv_gamemode 1")

-- Random Spawning Mode Enabled
-- "mp_randomspawn 0" = Random Spawning Mode Disabled
-- "mp_randomspawn 1" = Random Spawning Mode Enabled (Default)
-- parse("mp_randomspawn 1") -- Original CS2D Gun Game Default
parse("mp_randomspawn 1")

-- Infinite Ammo Mode Enabled
-- "mp_infammo 0" = Infinite Ammo Mode Disabled
-- "mp_infammo 1" = Infinite Ammo Mode Enabled (Default)
-- parse("mp_infammo 1") -- Original CS2D Gun Game Default
parse("mp_infammo 1")

-- Required Kills to Increase Level (Kills)
-- required_kills=3 -- Original CS2D Gun Game Default
required_kills=3

-- Enable Map Change and Melee Killing Spree (0 = Disabled, 1 = Enabled)
-- map_change_and_melee_killing_spree=1 -- Weeds Gun Game Default
map_change_and_melee_killing_spree=1

-- Map Change Delay for Melee Killing Spree (Seconds)
-- map_change_delay=30 -- Weeds Gun Game Default
map_change_delay=30

-- Weapon IDs for Different Levels ({WeaponID,WeaponID,WeaponID,etc...,50})
-- Note that the knife (Weapon ID "50") must be used for the last level.
-- sample.gg.wpn={45,48,49,30,38,20,21,10,4,50} -- Original CS2D Gun Game Default
-- sample.gg.wpn={1,2,3,4,5,6,10,11,20,21,22,23,24,30,31,32,33,34,35,36,37,38,39,40,45,46,47,48,49,90,91,50} -- Weeds Gun Game Default (All Weapons)
sample.gg.wpn={1,2,3,4,5,6,10,11,20,21,22,23,24,30,31,32,33,34,35,36,37,38,39,40,45,46,47,48,49,90,91,50}

-- Weapon ID Reference:
-- 1 = USP (KM .45 Tactical)
-- 2 = Glock (9x19mm Sidearm)
-- 3 = Deagle (Night Hawk .50C)
-- 4 = P228 (228 Compact)
-- 5 = Elites (.40 Dual Elites)
-- 6 = FiveSeven (ES Five-Seven)
-- 10 = M3 (Leone 12 Gauge Super Shotgun)
-- 11 = XM1014 (Leone YG1265 Auto Shotgun)
-- 20 = MP5 (KM Sub-Machine Gun)
-- 21 = TMP (Schmidt Machine Pistol)
-- 22 = P90 (ES C90)
-- 23 = MAC10 (Ingram MAC-10)
-- 24 = UMP45 (KM UMP45)
-- 30 = AK47 (CV-47)
-- 31 = SG552 (Krieg 552)
-- 32 = M4A1 (Maverick M4A1 Carbine)
-- 33 = AUG (Bullpup)
-- 34 = Scout (Schmidt Scout)
-- 35 = AWP (Magnum Sniper Rifle)
-- 36 = G3SG1 (D3/AU1)
-- 37 = SG550 (Krieg 550 Commando)
-- 38 = Gali (IDF Defender)
-- 39 = Famas (Clarion 5.56)
-- 40 = M249 (M249 Machine Gun)
-- 45 = Laser (Laser Gun)
-- 46 = Flamethrower (Flamethrower)
-- 47 = RPGLauncher (RPG Launcher)
-- 48 = RocketLauncher (Rocket Launcher)
-- 49 = GrenadeLauncher (Grenade Launcher)
-- 90 = M134 (M134 MiniGun)
-- 91 = FNF2000 (FN F2000 NATO Bullpup)
-- 50 = Knife (Melee Knife)
-- 58 = Kevlar and Helmet (Do NOT use for a weapon level, it is only listed here for reference.)


-----------------------
-- STARTROUND        --
-----------------------
addhook("startround","sample.gg.start")
function sample.gg.start()
	-- Reset Values
	local i
	for i=1,32 do
		sample.gg.level[i]=1
		sample.gg.kills[i]=0
		-- Reset Weapon (Kill)
		if (player(i,"exists")) then
			-- Strip All Weapons (0)
			parse("strip "..i.." 0")
			-- Give first Weapon
			parse("equip "..i.." "..sample.gg.wpn[1])
			-- Strip Knife
			parse("strip "..i.." 50")
		end
	end
end


-----------------------
-- JOIN              --
-----------------------
addhook("join","sample.gg.join")
function sample.gg.join(id)
	-- Reset Level with Join Server Handicap Level
	sample.gg.level[id]=join_server_handicap_level
	-- Reset Kills
	sample.gg.kills[id]=0
end

addhook("join","gun_game_join_server_message")
function gun_game_join_server_message(id)
	-- Gun Game Join Server Welcome Message
	msg2(id,"255255000This server is running a "..required_kills.."-Kill "..#sample.gg.wpn.."-Level Weeds Gun Game!@C")
	msg2(id,"255255000The current Gun Game Handicap starting level is Level "..join_server_handicap_level..".@C")
end


-----------------------
-- SPAWN             --
-----------------------
addhook("spawn","sample.gg.spawn")
function sample.gg.spawn(id)
	-- Minimum Level is 1
	if (sample.gg.level[id]<1) then
		sample.gg.level[id]=1
	end
	-- Remove Knife
	if (sample.gg.level[id]<#sample.gg.wpn) then
		parse("strip "..id.." 50")
	end
	-- Equip with Weapon for current Level
	if (sample.gg.level[id]>0 and sample.gg.level[id]<=#sample.gg.wpn) then
		parse("equip "..id.." 58") -- Give Kevlar and Helmet when spawning (Comment out to disable giving Kevlar and Helmet when spawning)
		return sample.gg.wpn[sample.gg.level[id]]
	end
end


-----------------------
-- KILL              --
-----------------------
addhook("kill","sample.gg.kill")
function sample.gg.kill(id)
	-- Add Kill
	sample.gg.kills[id]=sample.gg.kills[id]+1
	-- Give Kevlar and Helmet kill reward (Uncomment to enable giving Kevlar and Helmet kill reward)
	-- parse("equip "..id.." 58")
	-- Next Level?
	if (sample.gg.kills[id]>=required_kills) then
		-- Reset Kills
		sample.gg.kills[id]=0
		-- Increase Level
		sample.gg.level[id]=sample.gg.level[id]+1
		-- Player current level notification messages (Comment out to disable notification messages)
		msg2(id,"255000000You are now on level "..sample.gg.level[id].."!")
		-- Player current level notification sound effects (Comment out to disable notification sound effects)
		parse("sv_sound2 "..id.." Env/Alarm.wav")

		-- Win?
		if (sample.gg.level[id]>=#sample.gg.wpn) then
			msg("000255000"..player(id,"name").." has won the Gun Game!@C")
			-- Winner notification sound effect (Comment out to disable notification sound effect)
			parse("sv_sound Env/Siren.wav")
			if map_change_and_melee_killing_spree==1 then
				-- Melee killing spree on the same map after a player wins
				msg("255000000"..map_change_delay.." second melee killing spree before map change, take no prisoners!@C")
				msg(string.format("255255000Next Map: %s@C", game("nextmap")))
				freehook("kill","sample.gg.kill")
				addhook("spawn","melee_killing_spree_weapon_strip")
				function melee_killing_spree_weapon_strip()
					for i=1,32 do
						if (player(i,"exists")) then
							parse("strip "..i.." 0")
						end
					end
				return "x";
				end
				-- Change to the next map in the server's "MapCycle.cfg" file after a timed delay
				timer(map_change_delay*1000,"cyclemap")
				function cyclemap()
					parse("map "..game("nextmap"))
				end
			else
				-- Restart the Gun Game on the same map after a player wins
				-- (Does not change to the next map in the server's "MapCycle.cfg" file)
				parse("restart")
			end
		else
				if (sample.gg.level[id]>=#sample.gg.wpn-1) then
					-- Final level notification message (Comment out to disable notification message)
					msg("255000000"..player(id,"name").." is now on the final level!")
					-- Final level notification sound effect (Comment out to disable notification sound effect)
					parse("sv_sound Env/Siren.wav")
				else
					-- Next level notification messages (Comment out to disable notification messages)
					msg("000255000"..player(id,"name").." is now on level "..sample.gg.level[id].."!")
					-- Next level notification sound effects (Uncomment to enable notification sound effects)
					-- parse("sv_sound Env/Alarm.wav")
				end
			-- Give new Weapon
			parse("equip "..id.." "..sample.gg.wpn[sample.gg.level[id]])
			-- Remove last Weapon
			parse("strip "..id.." "..sample.gg.wpn[sample.gg.level[id]-1])
			-- Give Kevlar and Helmet level reward (Comment out to disable giving Kevlar and Helmet level reward)
			parse("equip "..id.." 58")
			-- Calculate Join Server Handicap Level
			for id=1,32 do
				if (player(id,'exists')) and (player(id,'team') ~= 0) then
					total_number_of_players=total_number_of_players+1
					sum_of_total_players_levels=sum_of_total_players_levels+sample.gg.level[id]
				end
			end
			join_server_handicap_level=sum_of_total_players_levels/total_number_of_players
			join_server_handicap_level=math.floor(join_server_handicap_level)
			-- Print current Join Server Handicap Level in the server's console (Comment out to disable printing the Handicap Level in the server's console)
			print("Current Join Server Handicap Level: "..join_server_handicap_level)
			sum_of_total_players_levels=0
			total_number_of_players=0
		end
	end
	-- Player Current Level and Kills Info
	if (sample.gg.level[id]<#sample.gg.wpn) then
		msg2(id,"255255000Level: "..sample.gg.level[id].." Kills: "..sample.gg.kills[id].." of "..required_kills)
	end
end


-----------------------
-- NO BUYING         --
-----------------------
addhook("buy","sample.gg.buy")
function sample.gg.buy()
	return 1
end


-----------------------
-- NO COLLECTING     --
-----------------------
addhook("walkover","sample.gg.walkover")
function sample.gg.walkover(id,iid,type)
	if (type>=61 and type<=68) then
		return 0
	end
	return 1
end


-----------------------
-- NO DROPPING       --
-----------------------
addhook("drop","sample.gg.drop")
function sample.gg.drop()
	return 1
end


-----------------------
-- NO DEAD DROPPING  --
-----------------------
addhook("die","sample.gg.die")
function sample.gg.die()
	return 1
end


-- EOF --